==> qtjambi-xmlpatterns-5.15.6-sources.jar: io/qt/xmlpatterns/QXmlItem.java <==
package io.qt.xmlpatterns;


/**
 * <p>Contains either an XML node or an atomic value</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmlitem.html">QXmlItem</a></p>
 */
public class QXmlItem extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#QXmlItem">QXmlItem::QXmlItem()</a></p>
     */
    public QXmlItem(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlItem instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#QXmlItem-3">QXmlItem::QXmlItem(QVariant)</a></p>
     */
    public QXmlItem(java.lang.Object atomicValue){
        super((QPrivateConstructor)null);
        initialize_native(this, atomicValue);
    }
    
    private native static void initialize_native(QXmlItem instance, java.lang.Object atomicValue);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#QXmlItem-1">QXmlItem::QXmlItem(QXmlItem)</a></p>
     */
    public QXmlItem(io.qt.xmlpatterns.QXmlItem other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QXmlItem instance, io.qt.xmlpatterns.QXmlItem other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#QXmlItem-2">QXmlItem::QXmlItem(QXmlNodeModelIndex)</a></p>
     */
    public QXmlItem(io.qt.xmlpatterns.QXmlNodeModelIndex node){
        super((QPrivateConstructor)null);
        initialize_native(this, node);
    }
    
    private native static void initialize_native(QXmlItem instance, io.qt.xmlpatterns.QXmlNodeModelIndex node);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#isAtomicValue">QXmlItem::isAtomicValue()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isAtomicValue(){
        return isAtomicValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isAtomicValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#isNode">QXmlItem::isNode()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isNode(){
        return isNode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isNode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#isNull">QXmlItem::isNull()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isNull(){
        return isNull_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isNull_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#toAtomicValue">QXmlItem::toAtomicValue()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object toAtomicValue(){
        return toAtomicValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object toAtomicValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#toNodeModelIndex">QXmlItem::toNodeModelIndex()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.xmlpatterns.QXmlNodeModelIndex toNodeModelIndex(){
        return toNodeModelIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xmlpatterns.QXmlNodeModelIndex toNodeModelIndex_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlItem(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QXmlItem clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QXmlItem clone_native(long __this_nativeId);
}

==> qtjambi-xmlpatterns-5.15.12-sources.jar: io/qt/xmlpatterns/QXmlItem.java <==
package io.qt.xmlpatterns;


/**
 * <p>Contains either an XML node or an atomic value</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmlitem.html">QXmlItem</a></p>
 */
public class QXmlItem extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#QXmlItem">QXmlItem::QXmlItem()</a></p>
     */
    public QXmlItem(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QXmlItem instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#QXmlItem-3">QXmlItem::QXmlItem(QVariant)</a></p>
     */
    public QXmlItem(java.lang.Object atomicValue){
        super((QPrivateConstructor)null);
        initialize_native(this, atomicValue);
    }
    
    private native static void initialize_native(QXmlItem instance, java.lang.Object atomicValue);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#QXmlItem-1">QXmlItem::QXmlItem(QXmlItem)</a></p>
     */
    public QXmlItem(io.qt.xmlpatterns.QXmlItem other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QXmlItem instance, io.qt.xmlpatterns.QXmlItem other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#QXmlItem-2">QXmlItem::QXmlItem(QXmlNodeModelIndex)</a></p>
     */
    public QXmlItem(io.qt.xmlpatterns.QXmlNodeModelIndex node){
        super((QPrivateConstructor)null);
        initialize_native(this, node);
    }
    
    private native static void initialize_native(QXmlItem instance, io.qt.xmlpatterns.QXmlNodeModelIndex node);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#isAtomicValue">QXmlItem::isAtomicValue()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isAtomicValue(){
        return isAtomicValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isAtomicValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#isNode">QXmlItem::isNode()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isNode(){
        return isNode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isNode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#isNull">QXmlItem::isNull()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isNull(){
        return isNull_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isNull_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#toAtomicValue">QXmlItem::toAtomicValue()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.Object toAtomicValue(){
        return toAtomicValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object toAtomicValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlitem.html#toNodeModelIndex">QXmlItem::toNodeModelIndex()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.xmlpatterns.QXmlNodeModelIndex toNodeModelIndex(){
        return toNodeModelIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.xmlpatterns.QXmlNodeModelIndex toNodeModelIndex_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlItem(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QXmlItem clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QXmlItem clone_native(long __this_nativeId);
}
